@@ -2,7 +2,6 @@
 #'
 #' @description Bayesian Estimation of Naloxone use Number Under-reporting
 #'
-#' @docType package
 #' @name bennu-package
 #' @aliases bennu
 #' @useDynLib bennu, .registration = TRUE
@@ -15,4 +14,4 @@
 #' @references
 #' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org
 #'
-NULL
+"_PACKAGE"
