@@ -1,3 +1,19 @@
+# default outputs of model to save
+the$default_outputs <- c(
+  "sim_p", "sim_used", "sim_reported_used", "c", "ct",
+  "sigma", "zeta", "mu0", "Distributed"
+)
+
+# default prior values
+the$default_priors <- list(
+  c = list(mu = 0, sigma = 1),
+  ct0 = list(mu = 0, sigma = 1),
+  zeta = list(mu = 0, sigma = 1),
+  mu0 = list(mu = 0, sigma = 1),
+  sigma = list(mu = 0, sigma = 1)
+)
+
+
 
 #' Run Bayesian estimation of naloxone number under-reporting
 #'
@@ -17,6 +33,8 @@
 #' @param delay_alpha shape parameter for order to distributed delay
 #' distribution
 #' @param delay_beta shape parameter for order to distributed delay distribution
+#' @param priors list of prior values including their mean (mu) and standard
+#'   deviation (sigma)
 #' @param run_estimation if `TRUE` will sample from posterior otherwise will
 #' sample from prior only
 #' @param rw_type `1` - random walk of order one. `2` - random walk of order 2.
@@ -27,6 +45,7 @@
 #' @param seed Seed for random number generation
 #' @param adapt_delta (double, between 0 and 1, defaults to 0.8)
 #' @param ... other parameters to pass to [rstan::sampling]
+#' @inheritParams rstan::sampling
 #' @family inference
 #' @return An S4 [rstan::stanfit] class object containing the fitted model
 #' @export
@@ -38,13 +57,18 @@ est_naloxone_vec <- function(N_region, N_t, N_distributed, regions,
                              max_delays = 3,
                              delay_alpha = 2,
                              delay_beta = 1,
+                             priors = the$default_priors,
                              run_estimation = TRUE,
                              rw_type = 1,
                              chains = 4,
                              iter = 2000,
                              seed = 42,
                              adapt_delta = 0.85,
+                             pars = the$default_outputs,
+                             include = TRUE,
                              ...) {
+  check_prior_format(priors)
+
   Orders <- as.vector(t(Orders2D))
 
   stan_data <-
@@ -94,10 +118,16 @@ est_naloxone_vec <- function(N_region, N_t, N_distributed, regions,
       Region_name = region_name,
 
       # // hyperpiors
-      mu0_mu = 0,
-      mu0_sigma = 1,
-      sigma_mu = 0,
-      sigma_sigma = 1
+      c_mu = priors$c$mu,
+      c_sigma = priors$c$sigma,
+      ct0_mu = priors$ct0$mu,
+      ct0_sigma = priors$ct0$sigma,
+      zeta_mu = priors$zeta$mu,
+      zeta_sigma = priors$zeta$sigma,
+      mu0_mu = priors$mu0$mu,
+      mu0_sigma = priors$mu0$sigma,
+      sigma_mu = priors$sigma$mu,
+      sigma_sigma = priors$sigma$sigma
     )
 
   fit <- rstan::sampling(
@@ -107,6 +137,8 @@ est_naloxone_vec <- function(N_region, N_t, N_distributed, regions,
     seed = seed, # fix seed to recreate results
     control = list(adapt_delta = adapt_delta),
     chains = chains,
+    pars = pars,
+    include = include,
     ...
   )
   return(fit)
@@ -135,7 +167,14 @@ est_naloxone_vec <- function(N_region, N_t, N_distributed, regions,
 #' options(mc.cores = parallel::detectCores(logical = FALSE))
 #'
 #' d <- generate_model_data()
-#' fit <- est_naloxone(d, iter = 100, chains = 1)
+#' priors <- list(
+#'   c = list(mu = 0, sigma = 1),
+#'   ct0 = list(mu = 0, sigma = 1),
+#'   zeta = list(mu = 0, sigma = 1),
+#'   mu0 = list(mu = 0, sigma = 1),
+#'   sigma = list(mu = 0, sigma = 1)
+#'   )
+#' fit <- est_naloxone(d, priors = priors, iter = 100, chains = 1)
 #' mcmc_pairs(fit,
 #'   pars = c("sigma", "mu0"),
 #'   off_diag_args = list(size = 1, alpha = 0.5)
@@ -150,12 +189,15 @@ est_naloxone <- function(d,
                          max_delays = 3,
                          delay_alpha = 2,
                          delay_beta = 1,
+                         priors = the$default_priors,
                          run_estimation = TRUE,
                          rw_type = 1,
                          chains = 4,
                          iter = 2000,
                          seed = 42,
                          adapt_delta = 0.85,
+                         pars = the$default_outputs,
+                         include = TRUE,
                          ...) {
   Orders <- NULL
 
@@ -205,14 +247,44 @@ est_naloxone <- function(d,
     max_delays = max_delays,
     delay_alpha = delay_alpha,
     delay_beta = delay_beta,
+    priors = priors,
     run_estimation = run_estimation,
     rw_type = rw_type,
     chains = chains,
     iter = iter,
     seed = seed,
     adapt_delta = adapt_delta,
+    pars = pars,
+    include = include,
     ...
   )
 
   return(obj)
 }
+
+#' check that the format of the priors matches with the default priors
+#' @noRd
+check_prior_format <- function(priors) {
+  if (!generics::setequal(
+    names(the$default_priors),
+    names(priors)
+  )) {
+    missing_priors <- generics::setdiff(
+      names(the$default_priors),
+      names(priors)
+    )
+    stop(
+      "Not all prior values defined. Missing priors are: ",
+      paste(missing_priors, collapse = ", ")
+    )
+  }
+
+  for (prior in names(the$default_priors)) {
+    if (!all(c("mu", "sigma") %in% names(priors[[prior]]))) {
+      stop(prior, " in priors should contain 'mu' and 'sigma'")
+    }
+    if (priors[[prior]]$sigma <= 0) {
+      stop("sigma for ", prior, " should be positive")
+    }
+  }
+}
